/*
 * openwms.org, the Open Warehouse Management System.
 *
 * This file is part of openwms.org.
 *
 * openwms.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * openwms.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software. If not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.openwms.common.domain {

    import flash.utils.IDataInput;
    import flash.utils.IDataOutput;
    import mx.collections.ListCollectionView;
    import org.granite.collections.IMap;
    import org.granite.collections.IPersistentCollection;
    import org.granite.meta;
    import org.granite.util.Enum;
    import org.openwms.common.domain.values.Barcode;
    import org.openwms.common.domain.values.TransportUnitState;
    import org.openwms.core.domain.AbstractEntity;
    import org.openwms.core.domain.DomainObject;
    import org.openwms.core.domain.system.usermanagement.User;

    use namespace meta;

    [Bindable]
    public class TransportUnitBase extends AbstractEntity implements DomainObject {

        private var __initialized:Boolean = true;
        private var __detachedState:String = null;

        protected var _actualLocation:Location;
        protected var _actualLocationDate:Date;
        protected var _barcode:Barcode;
        protected var _children:ListCollectionView;
        protected var _creationDate:Date;
        protected var _empty:Boolean;
        protected var _errors:IMap;
        protected var _id:Number;
        protected var _inventoryDate:Date;
        protected var _inventoryUser:User;
        protected var _parent:TransportUnit;
        protected var _state:TransportUnitState;
        protected var _targetLocation:Location;
        protected var _transportUnitType:TransportUnitType;
        protected var _version:Number;
        protected var _weight:Number;

        override meta function isInitialized(name:String = null):Boolean {
            if (!name)
                return __initialized;

            var property:* = this[name];
            return (
                (!(property is TransportUnit) || (property as TransportUnit).meta::isInitialized()) &&
                (!(property is IPersistentCollection) || (property as IPersistentCollection).isInitialized())
            );
        }

        public function set actualLocation(value:Location):void {
            _actualLocation = value;
        }
        public function get actualLocation():Location {
            return _actualLocation;
        }

        public function set actualLocationDate(value:Date):void {
            _actualLocationDate = value;
        }
        public function get actualLocationDate():Date {
            return _actualLocationDate;
        }

        public function set barcode(value:Barcode):void {
            _barcode = value;
        }
        public function get barcode():Barcode {
            return _barcode;
        }

        public function get children():ListCollectionView {
            return _children;
        }

        public function get creationDate():Date {
            return _creationDate;
        }

        public function set empty(value:Boolean):void {
            _empty = value;
        }

        public function get errors():IMap {
            return _errors;
        }

        public function get id():Number {
            return _id;
        }

        public function set inventoryDate(value:Date):void {
            _inventoryDate = value;
        }
        public function get inventoryDate():Date {
            return _inventoryDate;
        }

        public function set inventoryUser(value:User):void {
            _inventoryUser = value;
        }
        public function get inventoryUser():User {
            return _inventoryUser;
        }

        public function set parent(value:TransportUnit):void {
            _parent = value;
        }
        public function get parent():TransportUnit {
            return _parent;
        }

        public function set state(value:TransportUnitState):void {
            _state = value;
        }
        public function get state():TransportUnitState {
            return _state;
        }

        public function set targetLocation(value:Location):void {
            _targetLocation = value;
        }
        public function get targetLocation():Location {
            return _targetLocation;
        }

        public function set transportUnitType(value:TransportUnitType):void {
            _transportUnitType = value;
        }
        public function get transportUnitType():TransportUnitType {
            return _transportUnitType;
        }

        public function set version(value:Number):void {
            _version = value;
        }
        public function get version():Number {
            return _version;
        }

        public function set weight(value:Number):void {
            _weight = value;
        }
        public function get weight():Number {
            return _weight;
        }

        public function isNew():Boolean {
            return true;
        }

        override public function readExternal(input:IDataInput):void {
            __initialized = input.readObject() as Boolean;
            __detachedState = input.readObject() as String;
            if (meta::isInitialized()) {
                super.readExternal(input);
                _actualLocation = input.readObject() as Location;
                _actualLocationDate = input.readObject() as Date;
                _barcode = input.readObject() as Barcode;
                _children = input.readObject() as ListCollectionView;
                _creationDate = input.readObject() as Date;
                _empty = input.readObject() as Boolean;
                _errors = input.readObject() as IMap;
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
                _inventoryDate = input.readObject() as Date;
                _inventoryUser = input.readObject() as User;
                _parent = input.readObject() as TransportUnit;
                _state = Enum.readEnum(input) as TransportUnitState;
                _targetLocation = input.readObject() as Location;
                _transportUnitType = input.readObject() as TransportUnitType;
                _version = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
                _weight = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
            else {
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
        }

        override public function writeExternal(output:IDataOutput):void {
            output.writeObject(__initialized);
            output.writeObject(__detachedState);
            if (meta::isInitialized()) {
                super.writeExternal(output);
                output.writeObject(_actualLocation);
                output.writeObject(_actualLocationDate);
                output.writeObject(_barcode);
                output.writeObject(_children);
                output.writeObject(_creationDate);
                output.writeObject(_empty);
                output.writeObject(_errors);
                output.writeObject(_id);
                output.writeObject(_inventoryDate);
                output.writeObject(_inventoryUser);
                output.writeObject(_parent);
                output.writeObject(_state);
                output.writeObject(_targetLocation);
                output.writeObject(_transportUnitType);
                output.writeObject(_version);
                output.writeObject(_weight);
            }
            else {
                output.writeObject(_id);
            }
        }
    }
}