/*
 * openwms.org, the Open Warehouse Management System.
 *
 * This file is part of openwms.org.
 *
 * openwms.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * openwms.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software. If not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.openwms.common.domain.system {

    import flash.utils.IDataInput;
    import flash.utils.IDataOutput;
    import org.granite.collections.IPersistentCollection;
    import org.granite.meta;
    import org.openwms.core.domain.AbstractEntity;
    import org.openwms.core.domain.DomainObject;

    use namespace meta;

    [Bindable]
    public class UnitErrorBase extends AbstractEntity implements DomainObject {

        private var __initialized:Boolean = true;
        private var __detachedState:String = null;

        protected var _errorNo:String;
        protected var _errorText:String;
        protected var _id:Number;
        protected var _version:Number;

        override meta function isInitialized(name:String = null):Boolean {
            if (!name)
                return __initialized;

            var property:* = this[name];
            return (
                (!(property is UnitError) || (property as UnitError).meta::isInitialized()) &&
                (!(property is IPersistentCollection) || (property as IPersistentCollection).isInitialized())
            );
        }

        public function set errorNo(value:String):void {
            _errorNo = value;
        }
        public function get errorNo():String {
            return _errorNo;
        }

        public function set errorText(value:String):void {
            _errorText = value;
        }
        public function get errorText():String {
            return _errorText;
        }

        public function get id():Number {
            return _id;
        }

        public function set version(value:Number):void {
            _version = value;
        }
        public function get version():Number {
            return _version;
        }

        public function isNew():Boolean {
            return true;
        }

        override public function readExternal(input:IDataInput):void {
            __initialized = input.readObject() as Boolean;
            __detachedState = input.readObject() as String;
            if (meta::isInitialized()) {
                super.readExternal(input);
                _errorNo = input.readObject() as String;
                _errorText = input.readObject() as String;
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
                _version = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
            else {
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
        }

        override public function writeExternal(output:IDataOutput):void {
            output.writeObject(__initialized);
            output.writeObject(__detachedState);
            if (meta::isInitialized()) {
                super.writeExternal(output);
                output.writeObject(_errorNo);
                output.writeObject(_errorText);
                output.writeObject(_id);
                output.writeObject(_version);
            }
            else {
                output.writeObject(_id);
            }
        }
    }
}